Learn R Programming

XRJulia (version 0.9.0)

from_Julia-class: Class for General Julia Composite Type Objects

Description

The Julia side of the interface will return a general object from a composite type as an R object of class "from_Julia. its Julia fields (converted to R objects) can be accessed by the $ operator.

Arguments

Slots

serverClass

the Julia type.

module

the Julia module, or ""

fields

the converted versioin of the Julia fields; these are accessed by the $ operator.